/**************************************************************************//**
 * @file resetcause_low_voltage.c
 * @brief RMU and VCMP Demo Application
 * @author Silicon Labs
 * @version  1.10

 ******************************************************************************
 * @section License
 * <b>(C) Copyright 2014 Silicon Labs, http://www.silabs.com</b>
 *******************************************************************************
 *
 * Permission is granted to anyone to use this software for any purpose,
 * including commercial applications, and to alter it and redistribute it
 * freely, subject to the following restrictions:
 *
 * 1. The origin of this software must not be misrepresented; you must not
 *    claim that you wrote the original software.
 * 2. Altered source versions must be plainly marked as such, and must not be
 *    misrepresented as being the original software.
 * 3. This notice may not be removed or altered from any source distribution.
 *
 * DISCLAIMER OF WARRANTY/LIMITATION OF REMEDIES: Silicon Labs has no
 * obligation to support this Software. Silicon Labs is providing the
 * Software "AS IS", with no express or implied warranties of any kind,
 * including, but not limited to, any implied warranties of merchantability
 * or fitness for any particular purpose or warranties against infringement
 * of any proprietary rights of a third party.
 *
 * Silicon Labs will not be liable for any consequential, incidental, or
 * special damages, or any other relief, or for any claim by any third party,
 * arising from your use of this Software.
 *
 ******************************************************************************/

#include "em_device.h"
#include "em_chip.h"
#include "em_emu.h"
#include "em_cmu.h"
#include "display.h"
#include "stdio.h"
#include "textdisplay.h"
#include "em_rmu.h"
#include "retargettextdisplay.h"

#define VOLTAGE_LEVEL    2.2

uint32_t resetCause;

/***************************************************************************//**
 * @brief
 *   Displays reset cause on segment LCD
 ******************************************************************************/
void DisplayResetCause()
{
  printf("\n ");
  switch (resetCause)
  {
  case RMU_RSTCAUSE_PORST:
    printf("PORST");
    break;

  case RMU_RSTCAUSE_AVDDBOD:
    printf("AVDD");
    break;

  case RMU_RSTCAUSE_DVDDBOD:
    printf("DVDD");
    break;
    
  case RMU_RSTCAUSE_DECBOD:
    printf("DEC");
    break;

  case RMU_RSTCAUSE_EXTRST:
    printf("EXTRST");
    break;
    
  case RMU_RSTCAUSE_LOCKUPRST:
    printf("LOCKRST");
    break;

  case RMU_RSTCAUSE_SYSREQRST:
    printf("SYSRST");
    break;

  case RMU_RSTCAUSE_WDOGRST:
    printf("WDOGRST");
    break;

  }
}

/***************************************************************************//**
 * @brief
 *   Main function
 *
 * @details
 *   Reads the RESETCAUSE register and displays cause of reset on segment LCD
 *   Initializes VCMP for falling edge interrupt and enters EM2
 ******************************************************************************/
int main()
{
  /* Initialize chip */
  CHIP_Init();

  /* Read and clear reset cause register */
  resetCause = RMU_ResetCauseGet();
  RMU_ResetCauseClear();

  /* Initialize LCD and display reset cause */
  /* Initialize the STK's LCD */
  DISPLAY_Init();

  /* Retarget stdio to a text display. */
  if (RETARGET_TextDisplayInit() != TEXTDISPLAY_EMSTATUS_OK)
  {
    /* Text display initialization failed. */
    while (1);
  }

  DisplayResetCause();

  while (1)
  {
    EMU_EnterEM2(false);
  }
}

